<?php

/**
 * Plugin Name: ParOne Feeds
 * Plugin URI: https://docs.parone.com
 * Description: Tools for distributing ParOne video feeds in WordPress.
 * Version: 1.15.10
 * Author: ParOne, Inc.
 * License: GPLv3
 * License URI: https://www.gnu.org/licenses/gpl-3.0.html
 *
 * @package parone
 */

defined('ABSPATH') || exit;

function parone_shortcode_settings_init() {
  
  add_settings_section(
    'parone-shortcode-settings-section', // id of the section
    'ParOne Shortcode Settings', // title to be displayed
    'parone_shortcode_settings_section_cb', // callback
    'parone-shortcode-settings-page' // page on which to display the section
  );

  // register the setting
  register_setting(
    'parone-shortcode-settings-page', // option group
    'parone-default_parone_feed_id'
  );

  register_setting(
    'parone-shortcode-settings-page', // option group
    'parone-default_parone_env'
  );

  register_setting(
    'parone-shortcode-settings-page', // option group
    'parone-default_parone_autoplay'
  );

  register_setting(
    'parone-shortcode-settings-page', // option group
    'parone-default_parone_lang'
  );

  add_settings_field(
    'parone-default_parone_feed_id', // id of the settings field
    'ParOne Feed ID for shortcodes', // title
    'parone_set_shortcode_id_cb', // callback function
    'parone-shortcode-settings-page', // page on which settings display
    'parone-shortcode-settings-section' // section on which to show settings
  );
  
  
  add_settings_field(
    'parone-default_parone_env', // id of the settings field
    'Shortcode Environment', // title
    'parone_set_shortcode_env_cb', // callback function
    'parone-shortcode-settings-page', // page on which settings display
    'parone-shortcode-settings-section' // section on which to show settings
  );

  add_settings_field(
    'parone-default_parone_autoplay', // id of the settings field
    'Autoplay videos', // title
    'parone_set_shortcode_autoplay_cb', // callback function
    'parone-shortcode-settings-page', // page on which settings display
    'parone-shortcode-settings-section' // section on which to show settings
  );

  add_settings_field(
    'parone-default_parone_lang', // id of the settings field
    'Default Language for Titles and Descriptions', // title
    'parone_set_shortcode_lang_cb', // callback function
    'parone-shortcode-settings-page', // page on which settings display
    'parone-shortcode-settings-section' // section on which to show settings
  );
}


function parone_shortcode_settings_section_cb()
{
  echo "<p>Once you choose the ParOne environment and enter the feed slug from app.parone.com you'll be able to insert ParOne Videos into your site with the ParOne shortcodes.</p>";
}


// output script tag to change feed name
// save tab name in sanitize callback
function parone_set_shortcode_id_cb()
{
  echo '<input type="text" id="parone-default_parone_feed_id" name="parone-default_parone_feed_id" value="'. esc_attr(get_option('parone-default_parone_feed_id')) . '"/>';
}

function parone_set_shortcode_lang_cb()
{
  $parone_lang = get_option('parone-default_parone_lang', 'English');
  $theVar = parone_get_languages();
  echo '<select name="parone-default_parone_lang" id="parone-default_parone_lang">';
  foreach ($theVar as $key => $value)
  {
    $theLang = esc_attr($value);
    echo '<option value="' . esc_attr($theLang) . '"' . ($parone_lang == $theLang ? 'selected>' : '>') . esc_attr($theLang) . '</option>';
  }
  echo "</select>";
}

function parone_set_shortcode_env_cb()
{
  $parone_env = "prod";
  echo '<select name="parone-default_parone_env" id="parone-default_parone_env">';
  ?>
    <option value="prod" <?php if($parone_env == 'prod') echo 'selected'; ?>>
      Production
    </option>
  </select>
  <?php
}

function parone_set_shortcode_autoplay_cb()
{
  $parone_autoplay = get_option('parone-default_parone_autoplay', 'enabled');
  $theVar = ["1" => "enabled", "2" => "disabled"];
  echo '<select name="parone-default_parone_autoplay" id="parone-default_parone_autoplay">';
  foreach ($theVar as $anItem)
  {
    $anItem = esc_attr((string) $anItem);
    echo '<option value="' . esc_attr($anItem) . '"' . ($parone_autoplay == $anItem ? 'selected>' : '>') . esc_attr($anItem) . '</option>';
  }
  echo "</select>";
}

/*
  This function pulls the tab stuff from the stuff and stuffs it
*/
function parone_shortcode_settings_page_html() {
  ?>
  <h1> <?php esc_html_e( 'ParOne Shortcode Settings', 'parone' ); ?> </h1>
  <form method="POST" action="options.php">
  <?php
    // the feed name box changes the tab name
    settings_fields( 'parone-shortcode-settings-page' );
    do_settings_sections( 'parone-shortcode-settings-page' );
    submit_button();
  ?>
  </form>
  <div>
    <h3>Shortcode Usage</h3>
    <p>
    To inject ParOne videos anywhere in your site, use the following shortcodes:
    </p>
    <ul>
      <li> <code>[parone_video_player feed="FEED_ID" campaign="CAMPAIGN_ID" content-key="CONTENT_KEY"/]</code></li>
      <li> <code>[parone_video_playlist feed="FEED_ID"/]</code></li>
      <li> <code>[parone_thumbnail_carousel count="3"/]</code></li>
      <li> <code>[parone_vertical_thumbnail_carousel count="3"/]</code></li>
      <li> <code>[parone_playlist_carousel count="3"/]</code></li>
      <li> <code>[parone_video_block_playlist feed="FEED_ID"/]</code></li>
    </ul>
    <p>Note: if you don't specify a feed the default parone feed ID will be used (the one above).</p>
    <p>
    Detailed usage guidance is available at <a href="https://docs.parone.com/en/integration/wordpress/" target="_blank">https://docs.parone.com</a>.
    </p>
  </div>
  <?php
}


function parone_video_player_shortcode( $atts ) {
	$a = shortcode_atts( array( 'campaign' => '', 'content-key' => '', 'stylesheet' => '',
	    'feed' => '' , 'env' => '', 'autoplay' => 'none', 'autoplaymuted' => 'true', 
	    'defaultlang' => 'none', 'hide-title' => 'false', 
	    'hide-logo' => 'false', 'hide-description' => 'false', 'hide-all' => 'false'), $atts );
  $feed = $a['feed'] ? $a['feed'] : get_option('parone-default_parone_feed_id');
  $environment = $a['env'] ? $a['env'] : "prod";
  
  
  $autoplay = $a['autoplay'];
  if ($autoplay == "none") {
    $autoplay_setting = get_option('parone-default_parone_autoplay', "false");
    $autoplay = ($autoplay_setting == "enabled") ? "true" : "false";
  }
  $autoplay_mute = $a['autoplaymuted'];
  $default_lang = $a['defaultlang'];

  $hidetitle = $a['hide-title'];
  $hidelogo = $a['hide-logo'];
  $hidedesc = $a['hide-description'];
  $stylesheet = $a['stylesheet'];
  $hideall = $a['hide-all'];
    
  // our four content types. 
  $contentKey = $a['content-key'];    // is singular
  $campaign_id = $a['campaign'];      // old style campaign id
  $campaign_qv = get_query_var('parone_campaign_id') ? get_query_var('parone_campaign_id') : ''; // passed in as query
  
  $campaign_string = "";
  
  // if campaign is passed in use it
  if ($campaign_qv != '') {
    if (is_numeric($campaign_qv)) {
      $campaign_string = " campaign=\"${campaign_qv}\" ";
    } else {
      $campaign_string = " content-key=\"${campaign_qv}\" ";
    }
  } else {  // no passed in campaign. Prefer content-keys to content-key to campaign.
    $campaign_string =($contentKey == '' ? " campaign=\"${campaign_id}\" " : " content-key=\"${contentKey}\" ");
  }
  
  // fetch it
  if ($default_lang == 'none') {
    $language_code = get_option('parone-default_parone_lang', 'English');
    $default_lang = parone_get_language_code($language_code);
  }

  $styles = get_option('parone_video_player_styles', '');
  $sheetText = '';
  if ($stylesheet != '') {
    $sheetText = "stylesheet=\"${stylesheet}\"";
  } else if ($styles != '') {
    $sheetText = "stylesheet=\"{$styles}\"";
  }

  return "<parone-video-block feed=\"{$feed}\" env=\"{$environment}\" ${sheetText} autoplay=\"${autoplay}\" autoplaymuted=\"${autoplay_mute}\" defaultlang=\"${default_lang}\" hide-all=\"${hideall}\" hide-title=\"$hidetitle\" hide-logo=\"$hidelogo\" hide-description=\"$hidedesc\" ${campaign_string} ></parone-video-block>";

}

add_shortcode( 'parone_video_player', 'parone_video_player_shortcode' );

function parone_video_playlist_shortcode($atts) {
  $a = shortcode_atts( array( 'feed' => '' , 'content-keys' => '', 'env' => '', 'hide-card-title' => 'false', 'hide-card-description' => 'false', 'autoplay' => 'none', 'stylesheet' => '', 'autoplaymuted' => 'true', 'defaultlang' => 'none', 'hide-title' => 'false', 'hide-logo' => 'false', 'hide-description' => 'false', 'hide-all' => 'false', 'from' => '', 'to' => ''), $atts );
  $feed = $a['feed'] ? $a['feed'] : get_option('parone-default_parone_feed_id');
  $environment = $a['env'] ? $a['env'] : "prod";
  $styles = get_option('parone_video_playlist_styles');
  $from = $a['from'];
  $to = $a['to'];
  $autoplay = $a['autoplay'];
  if ($autoplay == "none") {
    $autoplay_setting = get_option('parone-default_parone_autoplay', "false");
    $autoplay = ($autoplay_setting == "enabled") ? "true" : "false";
  }
  $autoplay_mute = $a['autoplaymuted'];
  $default_lang = $a['defaultlang'];

  $hidetitle = $a['hide-title'];
  $hidelogo = $a['hide-logo'];
  $hidedesc = $a['hide-description'];
  $stylesheet = $a['stylesheet'];
  $contentKeys = $a['content-keys'];
  $hideall = $a['hide-all'];

  // we have to reformat contentKeys into a JSON quoted string
  $count = substr_count($contentKeys, ",");
  if ($count != 0) {
    $contentKeys = str_replace(",", "\",\"", $contentKeys);
    $contentKeys = "\"" . $contentKeys;
    $contentKeys .= "\"";
  }

  parone_logdebug("Content key: " . $contentKeys);
  parone_logdebug("Keys: " . json_encode($a));
 
  // fetch it
  if ($default_lang == 'none') {
    $language_code = get_option('parone-default_parone_lang', 'English');
    $default_lang = parone_get_language_code($language_code);
  }

  $text = $a['hide-card-title'];
  $hideCardTitle = " hide-card-title=" . '"' . $text . '" ';
  $text = $a['hide-card-description'];
  $hideCardDescription = " hide-card-description=" . '"' . $text . '" ';

  $styles = get_option('parone_video_player_styles', '');
  $sheetText = '';
  if ($stylesheet != '') {
    $sheetText = "stylesheet=\"${stylesheet}\"";
  } else if ($styles != '') {
    $sheetText = "stylesheet=\"{$styles}\"";
  }

  return "<parone-video-playlist env=\"{$environment}\" feed=\"{$feed}\" ${sheetText} $hideCardTitle $hideCardDescription content-keys='[$contentKeys]' autoplay=\"${autoplay}\" autoplaymuted=\"${autoplay_mute}\" defaultlang=\"${default_lang}\" hide-title=\"${hidetitle}\" hide-logo=\"${hidelogo}\" hide-description=\"${hidedesc}\" hide-all=\"${hideall}\" from=\"${from}\" to=\"${to}\"></parone-video-playlist>";
}
add_shortcode( 'parone_video_playlist', 'parone_video_playlist_shortcode' );

function parone_thumbnail_carousel_shortcode($atts) {
	$a = shortcode_atts( array( 'count' => '3', 'campaign' => '', 'feed' => '' , 'env' => '', 'defaultlang' => 'none', 'vertical' => '', 'from' => '', 'to' => '', 'stylesheet' => '', 'hide-title' => 'false', 'hide-logo' => 'false', 'hide-description' => 'false', 'hide-all' => 'false', 'autoplay' => 'none', 'autoplaymuted' => 'true'), $atts );
  $feed = $a['feed'] ? $a['feed'] : get_option('parone-default_parone_feed_id');
  $environment = $a['env'] ? $a['env'] : "prod";
  $default_lang = $a['defaultlang'];
  
  $from = $a['from'];
  $to = $a['to'];
  $vertical = $a['vertical'];
  
  $hidetitle = $a['hide-title'];
  $hidelogo = $a['hide-logo'];
  $hidedesc = $a['hide-description'];
  $hideall = $a['hide-all'];
  $autoplay = $a['autoplay'];
  if ($autoplay == "none") {
    $autoplay_setting = get_option('parone-default_parone_autoplay', "false");
    $autoplay = ($autoplay_setting == "enabled") ? "true" : "false";
  }
  $autoplay_mute = $a['autoplaymuted'];
  
  $verticalText = $vertical == 'true' ?" vertical=\"true\" " : "";
  
  // fetch it
  if ($default_lang == 'none') {
    $language_code = get_option('parone-default_parone_lang', 'English');
    $default_lang = parone_get_language_code($language_code);
  }

  $styles = get_option('parone_thumbnail_carousel_styles', '');
  $stylesheet = $a['stylesheet'];
  $sheetText = '';
  if ($stylesheet != '') {
    $sheetText = "stylesheet=\"${stylesheet}\"";
  } else if ($styles != '') {
    $sheetText = "stylesheet=\"{$styles}\"";
  }

	return "<parone-thumbnail-carousel env=\"{$environment}\" autoplay=\"${autoplay}\" autoplaymuted=\"${autoplay_mute}\" feed=\"{$feed}\" ${sheetText} ${verticalText} count=\"{$a['count']}\" defaultlang=\"${default_lang}\" hide-title=\"${hidetitle}\" hide-logo=\"${hidelogo}\" hide-description=\"${hidedesc}\" hide-all=\"${hideall}\" from=\"${from}\" to=\"${to}\"></parone-thumbnail-carousel>";
}
add_shortcode( 'parone_thumbnail_carousel', 'parone_thumbnail_carousel_shortcode' );

function parone_vertical_thumbnail_carousel_shortcode($atts) {
	$a = shortcode_atts( array( 'count' => '3', 'feed' => '', 'env' => '' , 'env' => '', 'defaultlang' => 'none', 'from' => '', 'to' => '', 'stylesheet' => ''), $atts );
  $feed = $a['feed'] ? $a['feed'] : get_option('parone-default_parone_feed_id');
  $environment = $a['env'] ? $a['env'] : "prod";
  $default_lang = $a['defaultlang'];
  
  $from = $a['from'];
  $to = $a['to'];
  
  // fetch it
  if ($default_lang == 'none') {
    $language_code = get_option('parone-default_parone_lang', 'English');
    $default_lang = parone_get_language_code($language_code);
  }

  $styles = get_option('parone_vertical_thumbnail_carousel_styles', '');
  $stylesheet = $a['stylesheet'];
  $sheetText = '';
  if ($stylesheet != '') {
    $sheetText = "stylesheet=\"${stylesheet}\"";
  } else if ($styles != '') {
    $sheetText = "stylesheet=\"{$styles}\"";
  }
	return "<parone-vertical-thumbnail-carousel env=\"{$environment}\" feed=\"{$feed}\" count=\"{$a['count']}\" defaultlang=\"${default_lang}\" ${sheetText} from=\"${from}\" to=\"${to}\"></parone-vertical-thumbnail-carousel>";
}
add_shortcode( 'parone_vertical_thumbnail_carousel', 'parone_vertical_thumbnail_carousel_shortcode' );

function parone_playlist_carousel_shortcode($atts) {
	$a = shortcode_atts( array( 'count' => '3', 'feed' => '', 'env' => '', 'autoplay' => 'none', 'autoplaymuted' => 'true', 'hide-card-title' => 'false', 'hide-distributor-logo' => 'false', 'defaultlang' => 'none', 'from' => '', 'to' => '', 'content-keys' => '', 'stylesheet' => '','hide-title' => 'false', 'hide-logo' => 'false', 'hide-description' => 'false','hide-all' => 'false'), $atts );
  $feed = $a['feed'] ? $a['feed'] : get_option('parone-default_parone_feed_id');
  $environment = $a['env'] ? $a['env'] : "prod";
  $autoplay = $a['autoplay'];
  if ($autoplay == "none") {
    $autoplay_setting = get_option('parone-default_parone_autoplay', "false");
    $autoplay = ($autoplay_setting == "enabled") ? "true" : "false";
  }
  $autoplay_mute = $a['autoplaymuted'];
  $default_lang = $a['defaultlang'];
  
  $from = $a['from'];
  $to = $a['to'];

  $hidetitle = $a['hide-title'];
  $hidelogo = $a['hide-logo'];
  $hidedesc = $a['hide-description'];
  $hideall = $a['hide-all'];
  $autoplay = $a['autoplay'];
  if ($autoplay == "none") {
    $autoplay_setting = get_option('parone-default_parone_autoplay', "false");
    $autoplay = ($autoplay_setting == "enabled") ? "true" : "false";
  }
  $autoplay_mute = $a['autoplaymuted'];
  $contentKeys = $a['content-keys'];


  $text = $a['hide-distributor-logo'];
  $distLogoText = " hide-distributor-logo=" . '"' . $text . '" ';
  
  $text = $a['hide-card-title'];
  $cardTitleText = " hide-card-title=" . '"' . $text . '" ';
  
  // we have to reformat contentKeys into a JSON quoted string
  $count = substr_count($contentKeys, ",");
  if ($count != 0) {
    $contentKeys = str_replace(",", "\",\"", $contentKeys);
    $contentKeys = "\"" . $contentKeys;
    $contentKeys .= "\"";
  }

  
  // fetch it
  if ($default_lang == 'none') {
    $language_code = get_option('parone-default_parone_lang', 'English');
    $default_lang = parone_get_language_code($language_code);
  }

  $styles = get_option('parone_playlist_carousel_styles', '');
  $stylesheet = $a['stylesheet'];
  $sheetText = '';
  if ($stylesheet != '') {
    $sheetText = "stylesheet=\"${stylesheet}\"";
  } else if ($styles != '') {
    $sheetText = "stylesheet=\"{$styles}\"";
  }

	return "<parone-playlist-carousel env=\"{$environment}\" feed=\"{$feed}\" content-keys='[$contentKeys]' $cardTitleText $distLogoText count=\"{$a['count']}\" autoplay=\"${autoplay}\" autoplaymuted=\"${autoplay_mute}\" defaultlang=\"${default_lang}\" hide-title=\"${hidetitle}\" hide-logo=\"${hidelogo}\" hide-description=\"${hidedesc}\" hide-all=\"${hideall}\" ${sheetText} from=\"${from}\" to=\"${to}\"></parone-playlist-carousel>";
}
add_shortcode( 'parone_playlist_carousel', 'parone_playlist_carousel_shortcode' );


function parone_video_block_playlist_shortcode($atts) {
	$a = shortcode_atts( array( 'feed' => '', 'env' => '' , 'content-keys' => '', 'autoplay' => 'none', 'shuffle' => 'false', 'stylesheet' => '', 'autoplaymuted' => 'true', 'defaultlang' => 'none', 'hide-title' => 'false', 'hide-logo' => 'false', 'hide-description' => 'false', 'from' => '', 'to' => '','hide-title' => 'false', 'hide-logo' => 'false', 'hide-description' => 'false','hide-all' => 'false'), $atts );
  $feed = $a['feed'] ? $a['feed'] : get_option('parone-default_parone_feed_id');
  $environment = $a['env'] ? $a['env'] : "prod";
  $autoplay = $a['autoplay'];
  if ($autoplay == "none") {
    $autoplay_setting = get_option('parone-default_parone_autoplay', "false");
    $autoplay = ($autoplay_setting == "enabled") ? "true" : "false";
  }
  $autoplay_mute = $a['autoplaymuted'];
  $default_lang = $a['defaultlang'];

  $from = $a['from'];
  $to = $a['to'];

  $hidetitle = $a['hide-title'];
  $hidelogo = $a['hide-logo'];
  $hidedesc = $a['hide-description'];
  $hideall = $a['hide-all'];
  $contentKeys = $a['content-keys'];
   // we have to reformat contentKeys into a JSON quoted string
  $count = substr_count($contentKeys, ",");
  if ($count != 0) {
    $contentKeys = str_replace(",", "\",\"", $contentKeys);
    $contentKeys = "\"" . $contentKeys;
    $contentKeys .= "\"";
  }

  $text = $a['shuffle'];
  $shuffleText = " shuffle=" . '"' . $text . '" ';
  
  // fetch it
  if ($default_lang == 'none') {
    $language_code = get_option('parone-default_parone_lang', 'English');
    $default_lang = parone_get_language_code($language_code);
  }

  $styles = get_option('parone_video_block_playlist_styles', '');
  $stylesheet = $a['stylesheet'];
  $sheetText = '';
  if ($stylesheet != '') {
    $sheetText = "stylesheet=\"${stylesheet}\"";
  } else if ($styles != '') {
    $sheetText = "stylesheet=\"{$styles}\"";
  }

	return "<parone-video-block-playlist env=\"{$environment}\" feed=\"{$feed}\" content-keys='[$contentKeys]' $shuffleText autoplay=\"${autoplay}\" autoplaymuted=\"${autoplay_mute}\" defaultlang=\"${default_lang}\"  hide-title=\"$hidetitle\" hide-logo=\"$hidelogo\" hide-description=\"$hidedesc\"  hide-all=\"$hideall\" ${sheetText} from=\"${from}\" to=\"${to}\"></parone-video-block-playlist>";
}
add_shortcode( 'parone_video_block_playlist', 'parone_video_block_playlist_shortcode' );
