<?php

/**
 * Plugin Name: ParOne Feeds
 * Plugin URI: https://docs.parone.com
 * Description: Tools for distributing ParOne video feeds in WordPress.
 * Version: 1.15.10
 * Author: ParOne, Inc.
 * License: GPLv3
 * License URI: https://www.gnu.org/licenses/gpl-3.0.html
 *
 * @package parone
 */

defined('ABSPATH') || exit;

function parone_styles_settings_init() {
  add_settings_section(
    'parone-style-settings-section', // id of the section
    'Stylesheets', // title to be displayed
    'parone_styles_settings_section_cb', // callback
    'parone-styles-page' // page on which to display the section
  );
  
  register_setting(
    'parone-styles-page', // option group
    'parone_thumbnail_carousel_styles'
  );

  register_setting(
    'parone-styles-page', // option group
    'parone_playlist_carousel_styles'
  );

  register_setting(
    'parone-styles-page', // option group
    'parone_vertical_thumbnail_carousel_styles'
  );
  
  register_setting(
    'parone-styles-page', // option group
    'parone_video_playlist_styles'
  );

  register_setting(
    'parone-styles-page', // option group
    'parone_video_player_styles'
  );

  register_setting(
    'parone-styles-page', // option group
    'parone_video_block_playlist_styles'
  );

  register_setting(
    'parone-styles-page', // option group
    'parone_custom_style_settings'
  );

  add_settings_field(
    'parone_custom_style_settings', // id of the settings field
    'Custom Styling', // title
    'parone_style_settings_cb', // callback function
    'parone-styles-page', // page on which settings display
    'parone-style-settings-section' // section on which to show settings
  );

  add_settings_field(
    'parone_thumbnail_carousel_styles', // id of the settings field
    'Custom Thumbnail Carousel Stylesheet', // title
    'parone_set_thumbnail_carousel_styles', // callback function
    'parone-styles-page', // page on which settings display
    'parone-style-settings-section' // section on which to show settings
  );

  add_settings_field(
    'parone_playlist_carousel_styles', // id of the settings field
    'Custom Playlist Carousel Stylesheet', // title
    'parone_set_playlist_carousel_styles', // callback function
    'parone-styles-page', // page on which settings display
    'parone-style-settings-section' // section on which to show settings
  );

  add_settings_field(
    'parone_vertical_thumbnail_carousel_styles', // id of the settings field
    'Custom Vertical Thumbnail Carousel Stylesheet', // title
    'parone_set_vertical_thumbnail_carousel_styles', // callback function
    'parone-styles-page', // page on which settings display
    'parone-style-settings-section' // section on which to show settings
  );
  
  add_settings_field(
    'parone_video_playlist_styles', // id of the settings field
    'Custom Video Playlist Stylesheet', // title
    'parone_set_video_playlist_styles', // callback function
    'parone-styles-page', // page on which settings display
    'parone-style-settings-section' // section on which to show settings
  );

  add_settings_field(
    'parone_video_player_styles', // id of the settings field
    'Custom Video Player Stylesheet', // title
    'parone_set_video_player_styles', // callback function
    'parone-styles-page', // page on which settings display
    'parone-style-settings-section' // section on which to show settings
  );
  
  add_settings_field(
    'parone_video_block_playlist_styles', // id of the settings field
    'Custom Video Block Playlist Stylesheet', // title
    'parone_set_video_block_playlist_styles', // callback function
    'parone-styles-page', // page on which settings display
    'parone-style-settings-section' // section on which to show settings
  );

}

function parone_styles_settings_section_cb()
{
  echo '<p>Customize the look and feel of the ParOne video player, video playlist, thumbnail carousel with a custom stylesheet. Enter the stylesheet URL as "https://STYLESHEET_URL".</p>';
}


  
function parone_styles_page_html() {
  ?>
  <form method="POST" action="options.php">
  <?php
    settings_fields( 'parone-styles-page' );
    do_settings_sections( 'parone-styles-page' );
    submit_button();
  ?>
  </form>
  <?php
}

function parone_set_thumbnail_carousel_styles()
{
  ?>
  <textarea rows="3" cols="50" id="parone_thumbnail_carousel_styles" name="parone_thumbnail_carousel_styles"><?php echo esc_textarea(get_option( 'parone_thumbnail_carousel_styles' )); ?></textarea>
  <?php

}

function parone_set_playlist_carousel_styles()
{
  ?>
  <textarea rows="3" cols="50" id="parone_playlist_carousel_styles" name="parone_playlist_carousel_styles"><?php echo esc_textarea(get_option( 'parone_playlist_carousel_styles' )); ?></textarea>
  <?php

}

function parone_set_vertical_thumbnail_carousel_styles()
{
  ?>
  <textarea rows="3" cols="50" id="parone_vertical_thumbnail_carousel_styles" name="parone_vertical_thumbnail_carousel_styles"><?php echo esc_textarea(get_option( 'parone_vertical_thumbnail_carousel_styles' )); ?></textarea>
  <?php

}

function parone_set_video_playlist_styles()
{
  ?>
  <textarea rows="3" cols="50" id="parone_video_playlist_styles" name="parone_video_playlist_styles"><?php echo esc_textarea(get_option( 'parone_video_playlist_styles' )); ?></textarea>
  <?php

}

function parone_set_video_player_styles()
{
  ?>
  <textarea rows="3" cols="50" id="parone_video_player_styles" name="parone_video_player_styles"><?php echo esc_textarea(get_option( 'parone_video_player_styles' )); ?></textarea>
  <?php

}

function parone_set_video_block_playlist_styles()
{
  ?>
  <textarea rows="3" cols="50" id="parone_video_block_playlist_styles" name="parone_video_block_playlist_styles"><?php echo esc_textarea(get_option( 'parone_video_block_playlist_styles' )); ?></textarea>
  <?php

}

function parone_style_settings_cb()
{
  ?>
  <input type="hidden" id="parone_custom_style_settings" name="parone_custom_style_settings" value="<?php echo esc_attr(get_option( 'parone_custom_style_settings' )); ?>"/>
  <parone-style-editor value="<?php echo esc_attr(get_option( 'parone_custom_style_settings' )); ?>"></parone-style-editor>
  <input id="style_editor_output" type="hidden"/>
  <script>
    (function(){
      let [el] = document.getElementsByTagName('parone-style-editor')
      el.addEventListener('styleUpdate', (event) => {
        parone_custom_style_settings.value = JSON.stringify(event.detail[0].styles)
      })
    })()
  </script>
  <?php

}
