<?php

/**
 * Plugin Name: ParOne Feeds
 * Plugin URI: https://docs.parone.com
 * Description: Tools for distributing ParOne video feeds in WordPress.
 * Version: 1.15.10
 * Author: ParOne, Inc.
 * License: GPLv3
 * License URI: https://www.gnu.org/licenses/gpl-3.0.html
 *
 * @package parone
 */

defined('ABSPATH') || exit;

// If the function it's not available, require it.
if ( ! function_exists( 'download_url' ) ) {
    require_once ABSPATH . 'wp-admin/includes/file.php';
}
// If the function it's not available, require it.
if ( ! function_exists( 'media_handle_sideload' ) ) {
    require_once ABSPATH . 'wp-admin/includes/media.php';
}
// If the function it's not available, require it.
if ( ! function_exists( 'wp_read_image_metadata' ) ) {
    require_once ABSPATH . 'wp-admin/includes/image.php';
}

$file_dir = untrailingslashit( dirname( __FILE__ ) );

require_once $file_dir . "/includes/parone_style_section.php";
require_once $file_dir . "/includes/parone_shortcode_section.php";
require_once $file_dir . "/includes/parone_video_section.php";
require_once $file_dir . "/includes/ISO639.php";

/**
  AI feature test. Set to true to enabled
**/
$parone_ai = false;

if ($parone_ai) {
  
  $parone_keyword_array = array(
    'lpga' => 337,
    'korda' => 368,
    'liv' => 302
  );

  add_action('save_post', 'parone_add_ai_codes');

  function parone_add_ai_codes($post_id) {

      $title = get_post_field('post_title', $post_id);
      $title = strtolower($title);
      
      $campaign_id = 0;
      // is one of the keys in the title?
      foreach ($parone_keyword_array as $key => $value) {
        if (str_contains($title, $key)) {
          $campaign_id = $value;
          break;
        }
      }
      
      // if so, edit the post body to add a video
      if ($campaign_id != 0) {
        $content = get_post_field('post_content', $post_id);
      
        if (str_contains($content, parone_video_player)) {
          $content = preg_replace('/campaign="(\d)+"/i', 'campaign="' . $campaign_id . '"', $content);
        } else {
              $content = $content . '<br>[parone_video_player campaign="' . $campaign_id . '" feed="1-all-videos" /]';		
        }
        // unhook this function so it doesn't loop infinitely
        remove_action('save_post', 'parone_add_ai_codes');

        // update the post, which calls save_post again
        wp_update_post(array('ID' => $post_id, 'post_content' => $content));

        // re-hook this function
        add_action('save_post', 'parone_add_ai_codes');
      }
  }  
}


/**
 * Load translations (if any) for the plugin from the /languages/ folder.
 * 
 * @link https://developer.wordpress.org/reference/functions/load_plugin_textdomain/
 */
add_action('init', 'parone_load_textdomain');

function parone_load_textdomain()
{
  load_plugin_textdomain('parone', false, basename(__DIR__) . '/languages');
}

/** 
 * Add custom image size for block featured image.
 * 
 * @link https://developer.wordpress.org/reference/functions/add_image_size/
 */
add_action('init', 'parone_add_image_size');

function parone_add_image_size()
{
  add_image_size('paroneFeatImg', 250, 250, array('center', 'center'));
}

/** 
 * Register custom image size with sizes list to make it available.
 * 
 * @link https://codex.wordpress.org/Plugin_API/Filter_Reference/image_size_names_choose
 */
add_filter('image_size_names_choose', 'parone_custom_sizes');

function parone_custom_sizes($sizes)
{
  return array_merge($sizes, array(
    'paroneFeatImg' => __('ParOne Featured Image'),
  ));
}

// our script asyncer
function parone_make_script_async( $tag, $handle, $src )
{
    $parone_script_handles = array("parone-sdk", "parone-thumbnail", "parone-network-videos");

    if (!in_array($handle, $parone_script_handles)) return $tag;

    return str_replace( '<script', '<script async', $tag );
}

add_filter( 'script_loader_tag', 'parone_make_script_async', 10, 3 );

// always use stage or prod depdning on defualts
function parone_plugin_scripts()
{
  wp_enqueue_script("parone-sdk", "https://sdk.parone.io/parone.min.js?v=1.15.10", array(), null, true);
  wp_enqueue_script("parone-thumbnail", "https://wp-thumbnail.parone.io/wp-thumbnail.js", array(), null, true);
}

// always use production scripts
function parone_admin_scripts()
{
  wp_enqueue_script("parone-sdk", "https://sdk.parone.io/parone.min.js?1.15.10", array(), null, true);
  wp_enqueue_script("parone-network-videos", "https://network-videos.parone.io/network-videos.umd.js", array(), null, true);
}

add_action('admin_enqueue_scripts', 'parone_admin_scripts');
add_action('wp_enqueue_scripts', 'parone_plugin_scripts');



function parone_logdebug($theMessage) {
  $parone_debug = false;
  if ($parone_debug) {
    $pluginlog = plugin_dir_path(__FILE__).'parone-debug.log';
   //error_log($theMessage . PHP_EOL, 3, $pluginlog);
  }
}


function parone_get_languages() {
  $language_url = "https://captions.parone.io/lang.json";
  $response = wp_remote_get($language_url);
  $data = $response['body'];
//    $data = file_get_contents($language_url);
  $response = json_decode($data);

  $iso = new Matriphe\ISO639\ISO639;
  
  $results = array();
  foreach ($response as $lang) {
    $result[$lang] = $iso->languageByCode1($lang);
  }
  return $result;
}

function parone_get_language_code($langName) {
  $langs = parone_get_languages();
  foreach ($langs as $key => $value) {
    if ($value == $langName) return $key;
  }
  return "en";
}

function parone_feed_settings_init($current_field_set) {
  parone_logdebug("feed suffix: " . $current_field_set);
  
  add_settings_section(
    'parone-feed-settings-section', // id of the section
    'Feed Information', // title to be displayed
    'parone_settings_section_cb', // callback
    'parone-settings-page' // page on which to display the section
  );

  // register the setting
  register_setting(
    'parone-settings-page', // option group
    'parone-default_parone_feed_id_' . $current_field_set
  );

  register_setting(
    'parone-settings-page', // option group
    'parone-default_parone_env_' . $current_field_set
  );

  add_settings_field(
    'parone-default_parone_feed_id_' . $current_field_set, // id of the settings field
    'ParOne Feed ID', // title
    'parone_set_feed_id_cb', // callback function
    'parone-settings-page', // page on which settings display
    'parone-feed-settings-section' // section on which to show settings
  );
  
  
  add_settings_field(
    'parone-default_parone_env_' . $current_field_set, // id of the settings field
    'ParOne Environment', // title
    'parone_set_feed_env_cb', // callback function
    'parone-settings-page', // page on which settings display
    'parone-feed-settings-section' // section on which to show settings
  );
}


function parone_settings_init() {
  global $parone_editing_feed_name;

  $parone_editing_feed_name = get_option('parone_editing_feed_name', 'default');
  
  parone_logdebug("In settings init: " . $parone_editing_feed_name);
  parone_feed_settings_init($parone_editing_feed_name);
  parone_shortcode_settings_init();
  parone_styles_settings_init();

}

add_action('admin_init', 'parone_settings_init');

function parone_admin_menu() {

  add_menu_page("ParOne Videos",       // page title
        "ParOne Videos",               // menu title
        "manage_options",             // capability
        "parone-shortcode-settings-page",       // slug
        "parone_shortcode_settings_page_html",  // function
        plugins_url('parone/parone.svg'));

  add_submenu_page("parone-shortcode-settings-page",  // parent slug
        "ParOne Stylesheets",                    // page title
        "Custom Stylesheets",                    // menu title
        "manage_options",                   // capability
        "parone-styles-page",               // slug
        "parone_styles_page_html");        // function

  add_submenu_page("parone-shortcode-settings-page",  // parent slug
        "ParOne Video Library",                    // page title
        "Video Library",                    // menu title
        "manage_options",                   // capability
        "parone-video-page",               // slug
        "parone_video_page_html");        // function
/*
  add to media page. there is a current_user_can on the video page.
  add_media_page(
        "ParOne Video Library",                    // page title
        "ParOne Video Library",                    // menu title
        "publish_posts",                   // capability
        "parone-video-page",               // slug
        "parone_video_page_html");        // function
*/
}

add_action('admin_menu', 'parone_admin_menu');


$parone_editing_feed_name = "extra";
// update here?
// phpcs:disable
if (isset( $_GET[ 'page' ] )) {
  $parone_editing_feed_name = isset( $_GET[ 'tab' ] ) ? $_GET[ 'tab' ] : 'default';
  update_option('parone_editing_feed_name', $parone_editing_feed_name);
  // replace options
//  parone_migrate_settings();
  
} else {
  parone_logdebug("page not set");
}
// phpcs:enable


// dynamic url re-writes when site owner creates a page with the permalink 'parone'

add_action( 'init', 'parone_rewrite_add_rewrites' );

function parone_rewrite_add_rewrites()
{

  $parone_page = NULL;
  if (function_exists('wpcom_vip_get_page_by_path')) {
    $parone_page = wpcom_vip_get_page_by_path('parone');
  } else {
    $parone_page = get_page_by_path('parone');
  }

  $parone_page_id = $parone_page ? $parone_page->ID : 1;
 
  add_rewrite_rule(
    'parone/([A-Za-z0-9_]+)[/]?$',
    'index.php?page_id='.$parone_page_id.'&parone_campaign_id=$matches[1]',
    'top'
  );

  add_filter( 'query_vars', function( $query_vars ) {
    $query_vars[] = 'parone_campaign_id';
    return $query_vars;
  } );

  add_action( 'template_include', function( $template ) {
    $output = NULL;
    if ( get_query_var( 'parone_campaign_id' ) == false || get_query_var( 'parone_campaign_id' ) == '' ) {
      return $template;
    }

    $parone_page = NULL;
    if (function_exists('wpcom_vip_get_page_by_path')) {
      $parone_page = wpcom_vip_get_page_by_path('parone');
    } else {
      $parone_page = get_page_by_path('parone');
    }
    if ( $parone_page == NULL ) {
      return plugin_dir_path( __FILE__ ) .'configuration-issue.php';
    } 

    return $template;
  } );
}

add_theme_support( 'align-wide' );

